@@ -1,2 +1,2 @@
 from .client import TradingAPI, ShoppingAPI, FindingAPI
-from .config import ebaysuds_config
+from .config import production_config, sandbox_config
